#
# spec file for package Photini
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           Photini
Version:        2022.3.2
Release:        bp155.3.6
Summary:        Digital photograph metadata (EXIF, IPTC, XMP) editing application
License:        GPL-3.0-or-later
Group:          Productivity/Graphics/Other
URL:            https://github.com/jim-easterbrook/Photini
Source0:        https://github.com/jim-easterbrook/Photini/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
# PATCH-FIX-OPENSUSE Photini-2021.1.0-desktop.patch fix desktop file -- aloisio@gmx.com
Patch0:         Photini-2021.1.0-desktop.patch
BuildRequires:  ImageMagick
BuildRequires:  fdupes
BuildRequires:  hicolor-icon-theme
BuildRequires:  python3-appdirs >= 1.3
BuildRequires:  python3-devel
BuildRequires:  python3-setuptools
Requires:       ffmpeg
Requires:       libgexiv2-2 >= 0.5
Requires:       python3-appdirs >= 1.3
Requires:       python3-gobject
Requires:       python3-gpxpy
Requires:       python3-keyring
Requires:       python3-qt5
Requires:       python3-qt5-sip
Requires:       python3-requests >= 2.4.0
Requires:       python3-requests-oauthlib
Requires:       typelib(GExiv2)
BuildArch:      noarch

%description
A digital photograph metadata (EXIF, IPTC, XMP) editing application.

"Metadata" is said to mean "data about data". In the context of digital
photographs, this means information that is not essential in order to display
the image, but tells something about it. For example, a title and
description of the scene or the date and time and the GPS coordinates of the
camera's position when the picture was taken.

%prep
%autosetup -p1

%build
python3 setup.py build
for s in 22 32 48 64 96 128 192 256 512; do
    convert -strip utils/make_icons/icon_master.png -resize ${s}x${s} ${s}.png
done

%install
python3 setup.py install --prefix=%{_prefix} --root=%{buildroot}
for s in 22 32 48 64 96 128 192 256 512; do
   mkdir -pv %{buildroot}%{_datadir}/icons//hicolor/${s}x${s}/apps
   install -m0644 ${s}.png -T \
        %{buildroot}%{_datadir}/icons/hicolor/${s}x${s}/apps/photini.png
done
install -Dm0644 src/photini/data/linux/photini.desktop \
   %{buildroot}%{_datadir}/applications/photini.desktop
rm -f %{buildroot}/%{python3_sitelib}/photini/data/linux/photini.desktop
%fdupes %{buildroot}

%files
%doc CHANGELOG.txt README.rst
%license LICENSE.txt
%{_bindir}/photini
%{python3_sitelib}/%{name}-%{version}-py%{py3_ver}.egg-info
%{python3_sitelib}/photini
%{_datadir}/applications/photini.desktop
%{_datadir}/icons/hicolor/*/apps/photini.png

%changelog
* Tue Oct 18 2022 pgajdos@suse.com
- python-six is not required
  https://trello.com/c/MO53MocR/143-remove-python3-six
* Wed Mar 30 2022 Luigi Baldoni <aloisio@gmx.com>
- Update to version 2022.3.2
  * Fix urllib import error porblem on some systems.
  * / Fix non-existing cache directory error.
* Tue Mar 22 2022 Luigi Baldoni <aloisio@gmx.com>
- Update to version 2022.3.1
  * Fix bug when removing marker from Bing map.
  * Fix bug in comparing version numbers.
* Thu Mar 17 2022 Luigi Baldoni <aloisio@gmx.com>
- Update to version 2022.3.0
  * Removed OpenStreetMap tab.
  * Added licence related stuf to ownership tab.
  * Removed --user option from post install script.
  * Better caching of geocoder results.
  * Other minor improvements and bug fixes.
* Wed Feb 16 2022 Luigi Baldoni <aloisio@gmx.com>
- Update to version 2022.2.0
  * Add uploader tab for "Ipernity" photo sharing club.
  * Substantial rewrite of uploader tabs.
  * Main window "maximised" state is saved.
  * Other minor improvements and bug fixes.
* Tue Jan  4 2022 Luigi Baldoni <aloisio@gmx.com>
- Update to version 2022.1.0
  * Improved spell check language menu.
  * Add option to read BMFF files.
  * Other minor improvements and bug fixes.
* Tue Dec  7 2021 Luigi Baldoni <aloisio@gmx.com>
- Update to version 2021.12.0
  * Installing with pip should install dependencies if needed.
  * Other minor improvements and bug fixes.
* Wed Nov 17 2021 Luigi Baldoni <aloisio@gmx.com>
- Update to version 2021.11.1
  * Fix problems regenerating thumbnails if Pillow & FFmpeg are
    not available.
  * Improved reading of Exif.Photo.UserComment values.
  * Minimum version of python-exiv2 is now 0.8.1
  * Other minor improvements and bug fixes.
* Wed Nov  3 2021 Luigi Baldoni <aloisio@gmx.com>
- Update to version 2021.11.0
  * Can use PySide6 instead of PySide2 or PyQt5.
  * New config option to enlarge user interface on high
    resolution screens.
  * Other minor improvements and bug fixes.
* Thu Sep 16 2021 Luigi Baldoni <aloisio@gmx.com>
- Update to version 2021.9.0
  * New option to set file timestamps to photo's taken date/time.
  * Improved GPX importer.
  * Add option to use python-exiv2 for metadata access.
* Mon Jul 12 2021 Luigi Baldoni <aloisio@gmx.com>
- Update to version 2021.7.0
  * Added a tab for 'ownership' and copyright details.
  * Added 'tooltip' hints to some text fields.
  * Try to ensure only one instance of Photini runs at a time.
  * Added menu option to make thumbnails for all images that
    have none.
  * Other minor improvements and bug fixes.
* Wed Jun 16 2021 Luigi Baldoni <aloisio@gmx.com>
- Update to version 2021.6.0
  * Show IPTC-IIM data length limits in text fields.
  * Drop use of Python FlickrAPI library.
  * Other minor improvements and bug fixes.
* Sat Apr  3 2021 aloisio@gmx.com
- Update to version 2021.4.0
  * Remove Python 2 and PyQt4 compatibility.
  * Cache map search and elevation results for improved speed.
  * Other minor improvements and bug fixes.
* Thu Jan 21 2021 Luigi Baldoni <aloisio@gmx.com>
- Update to version 2021.1.0
  * Technical tab now includes camera model.
  * Image list context menu now applies to all selected files.
  * Fix hang when importing files from a folder.
  * Can get thumbnails from more file types.
  * Minor other fixes and improvements.
- Replaced Photini-2020.12.1-desktop.patch with
  Photini-2021.1.0-desktop.patch
* Sat Jan  2 2021 Luigi Baldoni <aloisio@gmx.com>
- Update to version 2020.12.1
  * Can now use PySide2 instead of PyQt5.
  * Deprecated Python2 and PyQt4.
  * No longer creates menu entries during installation. Run
    photini-post-install after installation.
  * Minor other fixes and improvements.
- Add Photini-2020.12.1-desktop.patch
* Mon Nov 16 2020 Benjamin Greiner <code@bnavigator.de>
- Require the PyQt5.sip package instead of deprecated toplevel sip
* Sun Nov  8 2020 Luigi Baldoni <aloisio@gmx.com>
- Update to version 2020.11.0
  * Fix serious bug when saving "date taken" metadata.
* Sat Oct 31 2020 Luigi Baldoni <aloisio@gmx.com>
- Update to version 2020.10.1
  * Fix bug when using --root option on Linux installer.
  version 2020.10.0:
  * Fix bug when copying files from a high speed device.
  * Fix Google Photos uploader bug when folder has no name.
  * Improved installation, particularly start menu shortcuts.
  * Minor other fixes and improvements.
- Spec cleanup
* Tue Apr 28 2020 Luigi Baldoni <aloisio@gmx.com>
- Update to version 2020.4.0
  * Stopped using deprecated MapBox tile layers.
  * Many minor bug fixes and performance improvements.
* Mon Oct 28 2019 Luigi Baldoni <aloisio@gmx.com>
- Update to version 2019.10.1
  * Improved technical tab widgets. Units (e.g. mm) are now
    included in the display instead of the label, and blank or
    multiple values are handled better.
  * Several other bug fixes.
* Tue Oct 15 2019 Luigi Baldoni <aloisio@gmx.com>
- Update to version 2019.10.0
  * GPS coords address lookup is now on a separate tab.
  * Map tabs now display altitude as well as latitude &
    longitude.
  * File count shows progress during import.
  * Added 'move files' option to importer.
  * Added Czech and Catalan localisations.
  * Better handling of some non-standard metadata values.
  * Use FFmpeg instead of Exiv2 to read video file metadata.
* Tue Aug 20 2019 Luigi Baldoni <aloisio@gmx.com>
- Update to version 2019.8.0
  * Added new Google Photos uploader.
  * Improved login process for both uploaders.
  * Added GPX file (GPS track) importer to set approximate
    locations.
  * Made Photini extendable - can add tabs from other packages.
  * Improved reliability of maps, uploaders, and importer.
* Tue May 21 2019 Luigi Baldoni <aloisio@gmx.com>
- Update to version 2019.5.0
  * Added thumbnail context menu item to show metadata changes.
  * Use tabs to show 'camera' and multiple 'subject' addresses.
  * Can now synchronise Flickr metadata with local picture file.
  * Removed Google Photos uploader as the API it used is defunct.
  * Improved reliability when using PyGObject instead of pgi.
  * Improved error messages from GObject/GLib stuff.
* Tue Aug  7 2018 aloisio@gmx.com
- Update to version 2018.8.0
  * Removed Facebook tab. Their API no longer allows photo uploads.
  * Added "Mapbox" tab - OpenStreetMap data plus aerial imagery.
  * Many changes to maps, e.g. removing "load map" button.
  * Use OpenCage for all address lookups.
* Tue May  1 2018 aloisio@gmx.com
- Update to version 2018.5.0:
  * Improved calculation of "35mm equivalent" focal length.
  * Migrate spell check from PyEnchant to Gspell.
  * Use environment variable to set location of config file.
  * Copy more metadata to sidecar when it is created.
  * Fix problem with QtWebEngine and some PyQt versions.
  * Many other bug fixes and minor improvements.
- Dropped Photini-PyQt5-libGL.patch and Photini-Bing-map.patch
  (merged upstream)
* Wed Apr 25 2018 aloisio@gmx.com
- Added Photini-Bing-map.patch
* Wed Apr 25 2018 aloisio@gmx.com
- Added Photini-PyQt5-libGL.patch
* Sat Feb 10 2018 aloisio@gmx.com
- Update to 2018.2.0
  * All maps are faster and less buggy.
* Fri Dec  1 2017 aloisio@gmx.com
- Update to 2017.12.0
  * Add 'rating' to descriptive tab.
  * Don't try to upload files over 1 GByte to Flickr.
  * Fix bug with thembnails of portrait format images.
- Spec cleanup
* Tue Oct  3 2017 aloisio@gmx.com
- Update to 2017.10.0
  * Use timezone metadata from some Canon cameras.
  * Make thumbnails 160x120 as specified by DCF.
  * Fix bug in localisation of uploader tabs.
  * Substantial rewrite of metadata handling.
* Fri Aug 18 2017 aloisio@gmx.com
- Update to 2017.08.1
  * Added option to preserve file timestamps.
  * Added option to change copyright boilerplate text.
  * Added config file option to change application style.
  * Fix bug with importing files with spaces in their names.
  * Changed importer template marker from () to {}.
* Wed Aug  9 2017 aloisio@gmx.com
- Update to version 2017.8
  * Use Exif/Xmp thumbnails instead of computing from image data.
  * Improved video file metadata reading.
  * Added context menu to choose one of them.
  * Added context menu to image selector.
  * Can regenerate thumbnail, including from video files.
- Disabled tests (none was actually being performed)
* Fri Jun  2 2017 aloisio@gmx.com
- Update to version 2017.6
  * Add location address metadata to map tabs.
  * Fix bug in Flickr uploader if user hasn't set a "buddy" icon.
  * Use OpenCage Data for OSM map search and address lookup.
* Fri May  5 2017 jengelh@inai.de
- Remove redundant filler words from description.
* Tue May  2 2017 aloisio@gmx.com
- Added multiple icon sizes
* Tue May  2 2017 aloisio@gmx.com
- Update to version 2017.5
  * Migrate Bing map from v7 to v8 of Bing API.
  * Many other map improvements.
  * Time adjustment offset now includes time zone.
* Mon May  1 2017 adam.reichold@t-online.de
- Bump to latest upstream version
* Mon Feb 20 2017 aloisio@gmx.com
- Minor change
* Mon Feb 20 2017 aloisio@gmx.com
- Initial package (version 2016.12.0)
